
/* 
 Stepper Motor Control - one revolution
 
 This program drives a unipolar or bipolar stepper motor. 
 The motor is attached to digital pins 2 - 7 of the Arduino
 through an L293D motor controller IC as follows:
 Pins 2,4 and 5,7 are for In1, In2, In3, In4
 Pins 3 and 6 are for Enable1 and Enable2, respectively (as PWM outputs) 
 
 The motor should revolve one revolution in one direction, then
 one revolution in the other direction.  
 
  
 Created 11 Mar. 2007
 Modified 30 Nov. 2009
 by Tom Igoe
 
 Modified by Istvan Cserny on May 11, 2016.
 
 */

#include <Stepper.h>

const int stepsPerRevolution = 20;     // change this to fit the number of steps per revolution
                                       // for your motor
#define PWMA   3                       //L293D pin1  Enable1                                     
#define PWMB   6                       //L293D pin9  Enable2   

// initialize the stepper library on pins 8 through 11:
Stepper myStepper(stepsPerRevolution, 2,4,5,7);            

void setup() {
  pinMode(PWMA, OUTPUT); 
  pinMode(PWMB, OUTPUT);   
  setThrottle(0);
  myStepper.setSpeed(120);              // set the speed at 60 rpm:
  Serial.begin(9600);                  // initialize the serial port:
}

void loop() {
  Serial.println("clockwise");         // step one revolution  in one direction:
  setThrottle(255);  
  myStepper.step(stepsPerRevolution);
  setThrottle(64);
  delay(1000);
  
  Serial.println("counterclockwise");  // step one revolution in the other direction:
  setThrottle(255);  
  myStepper.step(-stepsPerRevolution);
  setThrottle(64);  
  delay(1000); 
}

void setThrottle(uint8_t duty) {
  digitalWrite(PWMA,duty);
  digitalWrite(PWMB,duty); 
} 

